#!/usr/bin/env node
"use strict";
const compiler_1 = require("./compiler");
const path = require("path");
const program = require("commander");
const Rx = require("rxjs/Rx");
const glob = require("glob");
const npmPackage = require(path.join(__dirname, '..', 'package.json'));
const globRx = Rx.Observable.bindNodeCallback(glob);
program
    .version(npmPackage.version);
program
    .command('compile <src...>')
    .description('compile words lists into simple dictionary files.')
    .option('-o, --output <path>', 'Specify the output directory, otherwise files are written back to the same location.')
    .option('-n, --no-compress', 'By default the files are Gzipped, this will turn that off.')
    .action((src, options) => {
    console.log('Compile:\n output: %s\n compress: %s\n files:\n  %s \n\n', options.output || 'default', options.compress ? 'true' : 'false', src.join('\n  '));
    const ext = options.compress ? '.gz' : '';
    Rx.Observable.from(src)
        .flatMap(src => globRx(src))
        .flatMap(s => s)
        .map(s => [s, options.output ? path.join(options.output, path.basename(s) + ext) : s + ext])
        .concatMap(([src, dst]) => {
        console.log('Process "%s" to "%s"', src, dst);
        return compiler_1.compileWordList(src, dst).then(() => src);
    })
        .forEach(name => console.log(`Complete.`));
});
program
    .command('compile-trie <src...>')
    .description('compile words lists into simple dictionary files.')
    .option('-o, --output <path>', 'Specify the output directory, otherwise files are written back to the same location.')
    .option('-n, --no-compress', 'By default the files are Gzipped, this will turn that off.')
    .action((src, options) => {
    console.log('Compile:\n output: %s\n compress: %s\n files:\n  %s \n\n', options.output || 'default', options.compress ? 'true' : 'false', src.join('\n  '));
    const ext = '.trie' + (options.compress ? '.gz' : '');
    Rx.Observable.from(src)
        .flatMap(src => globRx(src))
        .flatMap(s => s)
        .map(s => [s, options.output ? path.join(options.output, path.basename(s, '.txt') + ext) : s + ext])
        .concatMap(([src, dst]) => {
        console.log('Process "%s" to "%s"', src, dst);
        return compiler_1.compileTrie(src, dst).then(() => src);
    })
        .forEach(name => console.log(`Complete.`));
});
program.parse(process.argv);
if (!process.argv.slice(2).length) {
    program.help();
}
//# sourceMappingURL=app.js.map